yakumo.cinder.v1.volume

Package yakumo :: Package cinder :: Package v1 :: Module volume |
[hide private]
[frames] | no frames]

# Module volume

source code

Resource class and its manager for volumes on Block Storage V1 API

Classes | [hide private]
| Resource resource class for volumes on Block Storage V1 API
| Manager manager class for roles on Block Storage V1 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v1``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'display_name', mapper.Noop), ('d
      escription', 'display_description', mapper.Noop), ('availability_zone'
      , 'availability_zone', mapper.Noop), ('size', 'size', mapper.Noop), ('
      status', 'status', mapper.Noop), ('attachments', 'attachments', mapper
      .Noop), ('volume_type', 'volume_type', mapper.Resource('cinder.volume_
      type')), ('source_image', 'imageRef', mapper.Resource('image')), ('sou
      rce_snapshot', 'snapshot_id', mapper.Resource('cinder.volume_snapshot'
      )), ('source_volume', 'source_volid', mapper.Resource('cinder.volume')
      ...